# Examples

This folder contains some examples of building data visualizations and other neat things using
iNaturalist data. See [documentation](https://pyinaturalist.readthedocs.io/en/stable/examples.html)
for more details.

## Example visualizations
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/niconoe/pyinaturalist/main?filepath=examples)

![](images/total_observations_by_iconic_taxon.png)

![](images/total_taxa_by_iconic_taxon.png)

![](images/combined_activity_stats.png)

![](images/observations_by_date_and_time.png)
